compare_json_numbers

Function compare_json_numbers 

pub fn compare_json_numbers<S, O>(
    self_input: S,
    other_input: O,
) -> Option<Ordering>
Compare json numbers

While this function can be called with two strings, it would not make sense because javascript does not use numeric comparisons for strings