pub fn compare_json_numbers<S, O>(
self_input: S,
other_input: O,
) -> Option<Ordering>Expand description
Compare json numbers
While this function can be called with two strings, it would not make sense because javascript does not use numeric comparisons for strings